@@ -11,7 +11,10 @@ class SAML2_ArtifactResponse extends SAML2_StatusResponse {
 
 
 	/**
-	 * @var any contains saml2message XML
+	 * The DOMElement with the message the artifact refers
+	 * to, or NULL if we don't refer to any artifact.
+	 *
+	 * @var DOMElement|NULL
 	 */
 	private $any;
 
@@ -38,8 +41,7 @@ class SAML2_ArtifactResponse extends SAML2_StatusResponse {
 	}
 
 
-	public function setAny(DOMElement $any) {
-		assert('!is_null($any)');
+	public function setAny(DOMElement $any = NULL) {
 		$this->any = $any;
 	}
 
