@@ -28,6 +28,16 @@ class SimpleSAML_Auth_Simple {
 	}
 
 
+	/**
+	 * Retrieve the implementing authentication source.
+	 *
+	 * @return SimpleSAML_Auth_Source  The authentication source.
+	 */
+	public function getAuthSource() {
+		return SimpleSAML_Auth_Source::getById($this->authSource);
+	}
+
+
 	/**
 	 * Check if the user is authenticated.
 	 *
