@@ -15,13 +15,42 @@
  */
 class SimpleSAML_Error_UnserializableException extends SimpleSAML_Error_Exception {
 
+	/**
+	 * The classname of the original exception.
+	 *
+	 * @var string
+	 */
+	private $class;
+
+
+	/**
+	 * Create a serializable exception representing an unserializable exception.
+	 *
+	 * @param Exception $original  The original exception.
+	 */
 	public function __construct(Exception $original) {
 
-		$msg = get_class($original) . ': ' . $original->getMessage();
+		$this->class = get_class($original);
+		$msg = $original->getMessage();
 		$code = $original->getCode();
-		parent::__construct($msg, $code);
 
-		$this->setBacktrace(SimpleSAML_Utilities::buildBacktrace($original));
+		if (!is_int($code)) {
+			/* PDOException uses a string as the code. Filter it out here. */
+			$code = -1;
+		}
+
+		parent::__construct($msg, $code);
+		$this->initBacktrace($original);
 	}
 
-}
\ No newline at end of file
+
+	/**
+	 * Retrieve the class of this exception.
+	 *
+	 * @return string  The classname.
+	 */
+	public function getClass() {
+		return $this->class;
+	}
+
+}
