@@ -116,18 +116,38 @@ class SimpleSAML_Memcache {
 	 *
 	 * @param $key    The key of the data.
 	 * @param $value  The value of the data.
+	 * @param int|NULL $expire  The expiration timestamp of the data.
 	 */
-	public static function set($key, $value) {
+	public static function set($key, $value, $expire = NULL) {
 		$savedInfo = array(
 			'timestamp' => microtime(TRUE),
 			'data' => $value
 			);
 
+		if ($expire === NULL) {
+			$expire = self::getExpireTime();
+		}
+
 		$savedInfoSerialized = serialize($savedInfo);
 
 		/* Store this object to all groups of memcache servers. */
 		foreach(self::getMemcacheServers() as $server) {
-			$server->set($key, $savedInfoSerialized, 0, self::getExpireTime());
+			$server->set($key, $savedInfoSerialized, 0, $expire);
+		}
+	}
+
+
+	/**
+	 * Delete a key-value pair from the memcache servers.
+	 *
+	 * @param string $key  The key we should delete.
+	 */
+	public static function delete($key) {
+		assert('is_string($key)');
+
+		/* Store this object to all groups of memcache servers. */
+		foreach(self::getMemcacheServers() as $server) {
+			$server->delete($key);
 		}
 	}
 
@@ -229,12 +249,13 @@ class SimpleSAML_Memcache {
 	 * @return A Memcache object of the servers in the group.
 	 */
 	private static function loadMemcacheServerGroup(array $group) {
+
+		if(!class_exists('Memcache')) {
+			throw new Exception('Missing Memcache class. Is the memcache extension installed?');
+		}
+
 		/* Create the Memcache object. */
 		$memcache = new Memcache();
-		if($memcache == NULL) {
-			throw new Exception('Unable to create an instance of a Memcache object.' .
-				' Is the memcache extension installed?');
-		}
 
 		/* Iterate over all the servers in the group and add them to the Memcache object. */
 		foreach($group as $index => $server) {
