@@ -139,8 +139,8 @@ class SimpleSAML_XHTML_IdPDisco {
 			$this->setIdPentityID = NULL;
 		}
 
-		if (array_key_exists('IDPList', $_GET)) {
-			$this->scopedIDPList = $_GET['IDPList'];
+		if (array_key_exists('IDPList', $_REQUEST)) {
+			$this->scopedIDPList = $_REQUEST['IDPList'];
 		}
 
 	}
@@ -351,6 +351,19 @@ class SimpleSAML_XHTML_IdPDisco {
 	}
 
 
+	/**
+	 * Save the current IdP choice to a cookie.
+	 *
+	 * @param string $idp  The entityID of the IdP.
+	 */
+	protected function setPreviousIdP($idp) {
+		assert('is_string($idp)');
+
+		$this->log('Choice made [' . $idp . '] Setting cookie.');
+		$this->setCookie('lastidp', $idp);
+	}
+
+
 	/**
 	 * Determine whether the choice of IdP should be saved.
 	 *
@@ -380,9 +393,7 @@ class SimpleSAML_XHTML_IdPDisco {
 		$idp = $this->getSelectedIdP();
 		if($idp !== NULL) {
 			/* The user selected this IdP. Save the choice in a cookie. */
-
-			$this->log('Choice made [' . $idp . '] Setting cookie.');
-			$this->setCookie('lastidp', $idp);
+			$this->setPreviousIdP($idp);
 
 			if($this->saveIdP()) {
 				$this->setCookie('remember', 1);
