@@ -12,10 +12,12 @@ $associations = $idp->getAssociations();
 
 if (!isset($_REQUEST['cancel'])) {
 	SimpleSAML_Logger::stats('slo-iframe done');
+	SimpleSAML_Stats::log('core:idp:logout-iframe:page', array('type' => 'done'));
 	$SPs = $state['core:Logout-IFrame:Associations'];
 } else {
 	/* User skipped global logout. */
 	SimpleSAML_Logger::stats('slo-iframe skip');
+	SimpleSAML_Stats::log('core:idp:logout-iframe:page', array('type' => 'skip'));
 	$SPs = array(); /* No SPs should have been logged out. */
 	$state['core:Failed'] = TRUE; /* Mark as partial logout. */
 }
@@ -52,6 +54,7 @@ foreach ($SPs as $assocId => $sp) {
 			$spId = $assocId;
 		}
 		SimpleSAML_Logger::stats('slo-iframe-fail ' . $spId);
+		SimpleSAML_Stats::log('core:idp:logout-iframe:spfail', array('sp' => $spId));
 		$state['core:Failed'] = TRUE;
 	}
 
