@@ -46,6 +46,11 @@ class sspmod_ldap_ConfigHelper {
 	 */
 	private $timeout;
 
+	/**
+	 * Whether to follow referrals
+	 */
+	private $referrals;
+
 
 	/**
 	 * Whether we need to search for the users DN.
@@ -126,6 +131,7 @@ class sspmod_ldap_ConfigHelper {
 		$this->enableTLS = $config->getBoolean('enable_tls', FALSE);
 		$this->debug = $config->getBoolean('debug', FALSE);
 		$this->timeout = $config->getInteger('timeout', 0);
+		$this->referrals = $config->getBoolean('referrals', TRUE);
 		$this->searchEnable = $config->getBoolean('search.enable', FALSE);
 		$this->privRead = $config->getBoolean('priv.read', FALSE);
 
@@ -172,7 +178,7 @@ class sspmod_ldap_ConfigHelper {
 			throw new SimpleSAML_Error_Error('WRONGUSERPASS');
 		}
 
-		$ldap = new SimpleSAML_Auth_LDAP($this->hostname, $this->enableTLS, $this->debug, $this->timeout);
+		$ldap = new SimpleSAML_Auth_LDAP($this->hostname, $this->enableTLS, $this->debug, $this->timeout, 389, $this->referrals);
 
 		if (!$this->searchEnable) {
 			$ldapusername = addcslashes($username, ',+"\\<>;*');
@@ -239,7 +245,9 @@ class sspmod_ldap_ConfigHelper {
 		$ldap = new SimpleSAML_Auth_LDAP($this->hostname,
 			$this->enableTLS,
 			$this->debug,
-			$this->timeout);
+			$this->timeout,
+			389,
+			$this->referrals);
 
 		if ($attribute == NULL)
 			$attribute = $this->searchAttributes;
@@ -255,7 +263,9 @@ class sspmod_ldap_ConfigHelper {
 		$ldap = new SimpleSAML_Auth_LDAP($this->hostname,
 			$this->enableTLS,
 			$this->debug,
-			$this->timeout);
+			$this->timeout,
+			389,
+			$this->referrals);
 
 		return $ldap->getAttributes($dn, $attributes);
 	}
