@@ -7,7 +7,7 @@ require_once(dirname(dirname(__FILE__)) . '/libextinc/OAuth.php');
  *
  * @author Andreas Åkre Solberg, <andreas.solberg@uninett.no>, UNINETT AS.
  * @package simpleSAMLphp
- * @version $Id: Consumer.php 2099 2010-01-12 07:04:29Z andreassolberg $
+ * @version $Id: Consumer.php 2734 2011-02-08 13:50:51Z olavmrk $
  */
 class sspmod_oauth_Consumer {
 	
@@ -22,14 +22,59 @@ class sspmod_oauth_Consumer {
 	// Used only to load the libextinc library early.
 	public static function dummy() {}
 	
-	public function getRequestToken($url) {
-		$req_req = OAuthRequest::from_consumer_and_token($this->consumer, NULL, "GET", $url, NULL);
+	
+	public static function getOAuthError($hrh) {
+		foreach($hrh AS $h) {
+			if (preg_match('|OAuth-Error:\s([^;]*)|i', $h, $matches)) {
+				return $matches[1];
+			}
+		}
+		return null;
+	}
+	
+	public static function getContentType($hrh) {
+		foreach($hrh AS $h) {
+			if (preg_match('|Content-Type:\s([^;]*)|i', $h, $matches)) {
+				return $matches[1];
+			}
+		}
+		return null;
+	}
+	
+	/*
+	 * This static helper function wraps file_get_contents
+	 * and throws an exception with diagnostics messages if it appear
+	 * to be failing on an OAuth endpoint.
+	 * 
+	 * If the status code is not 200, an exception is thrown. If the content-type
+	 * of the response if text/plain, the content of the response is included in 
+	 * the text of the Exception thrown.
+	 */
+	public static function getHTTP($url, $context = '') {
+		$response = @file_get_contents($url);
+		
+		if ($response === FALSE) {
+			$statuscode = 'unknown';
+			if (preg_match('/^HTTP.*\s([0-9]{3})/', $http_response_header[0], $matches)) $statuscode = $matches[1];
+			
+			$error = $context . ' [statuscode: ' . $statuscode . ']: ';
+			$contenttype = self::getContentType($http_response_header);
+			$oautherror = self::getOAuthError($http_response_header);
+			
+			if (!empty($oautherror)) $error .= $oautherror;
+
+			throw new Exception($error . ':' . $url);
+		} 
+		// Fall back to return response, if could not reckognize HTTP header. Should not happen.
+		return $response;
+	}
+	
+	public function getRequestToken($url, $parameters = NULL) {
+		$req_req = OAuthRequest::from_consumer_and_token($this->consumer, NULL, "GET", $url, $parameters);
 		$req_req->sign_request($this->signer, $this->consumer, NULL);
 
-		$response_req = file_get_contents($req_req->to_url());
-		if ($response_req === FALSE) {
-			throw new Exception('Error contacting request_token endpoint on the OAuth Provider');
-		}
+		$response_req = self::getHTTP($req_req->to_url(), 
+			'Contacting request_token endpoint on the OAuth Provider');
 
 		parse_str($response_req, $responseParsed);
 		
@@ -54,9 +99,9 @@ class sspmod_oauth_Consumer {
 		return $authorizeURL;
 	}
 	
-	public function getAccessToken($url, $requestToken) {
+	public function getAccessToken($url, $requestToken, $parameters = NULL) {
 
-		$acc_req = OAuthRequest::from_consumer_and_token($this->consumer, $requestToken, "GET", $url, NULL);
+		$acc_req = OAuthRequest::from_consumer_and_token($this->consumer, $requestToken, "GET", $url, $parameters);
 		$acc_req->sign_request($this->signer, $this->consumer, $requestToken);
 		
 		$response_acc = file_get_contents($acc_req->to_url());
@@ -104,12 +149,15 @@ class sspmod_oauth_Consumer {
 		return $response;
 	}
 	
-	public function getUserInfo($url, $accessToken) {
+	public function getUserInfo($url, $accessToken, $opts = NULL) {
 		
 		$data_req = OAuthRequest::from_consumer_and_token($this->consumer, $accessToken, "GET", $url, NULL);
 		$data_req->sign_request($this->signer, $this->consumer, $accessToken);
 
-		$data = file_get_contents($data_req->to_url());
+		if (is_array($opts)) {
+			$opts = stream_context_create($opts);
+		}
+		$data = file_get_contents($data_req->to_url(), FALSE, $opts);
 		#print_r($data);
 
 		$dataDecoded = json_decode($data, TRUE);
