@@ -551,14 +551,14 @@ class sspmod_saml_IdP_SAML2 {
 	 *
 	 * @param SimpleSAML_IdP $idp  The IdP the association belongs to.
 	 * @param array $association  The SP association.
-	 * @return SimpleSAML_Configuration|NULL  Configuration object for the SP metadata.
+	 * @return SimpleSAML_Configuration  Configuration object for the SP metadata.
 	 */
 	public static function getAssociationConfig(SimpleSAML_IdP $idp, array $association) {
 		$metadata = SimpleSAML_Metadata_MetaDataStorageHandler::getMetadataHandler();
 		try {
 			return $metadata->getMetaDataConfig($association['saml:entityID'], 'saml20-sp-remote');
 		} catch (Exception $e) {
-			SimpleSAML_Configuration::loadFromArray(array(), 'Unknown SAML 2 entity.');
+			return SimpleSAML_Configuration::loadFromArray(array(), 'Unknown SAML 2 entity.');
 		}
 	}
 
