@@ -10,7 +10,7 @@ $this->includeAtTemplateBase('includes/header.php');
 if (count($this->data['errors']) > 0) {
 ?>
 <div style="border: 1px solid #800; background: #caa; margin: 1em; padding: .5em">
-<p><?php echo '<img style="float: right" src="/' . $this->data['baseurlpath'] . 'resources/icons/silk/delete.png" alt="Failed" />'; ?>	
+<p><?php echo '<img class="float-r" src="/' . $this->data['baseurlpath'] . 'resources/icons/silk/delete.png" alt="Failed" />'; ?>	
 These checks failed:</p>
 <?php
 
@@ -28,7 +28,7 @@ echo '</div>';
 if (count($this->data['info']) > 0) {
 ?>
 <div style="border: 1px solid #ccc; background: #eee; margin: 1em; padding: .5em">
-<p><?php echo '<img style="float: right" src="/' . $this->data['baseurlpath'] . 'resources/icons/silk/accept.png" alt="OK" />'; ?>	
+<p><?php echo '<img class="float-r" src="/' . $this->data['baseurlpath'] . 'resources/icons/silk/accept.png" alt="OK" />'; ?>	
 These checks succeeded:</p>
 <?php
 	echo '<ul>';
