@@ -1,18 +1,12 @@
 <?php
-
-
-
 if(!empty($this->data['htmlinject']['htmlContentPost'])) {
 	foreach($this->data['htmlinject']['htmlContentPost'] AS $c) {
 		echo $c;
 	}
 }
-
-
 ?>
-
-
-
+	</div><!-- #content -->
+	<div id="footer">
 		<hr />
 
 		<img src="/<?php echo $this->data['baseurlpath']; ?>resources/icons/ssplogo-fish-small.png" alt="Small fish logo" style="float: right" />		
@@ -20,9 +14,9 @@ if(!empty($this->data['htmlinject']['htmlContentPost'])) {
 		
 		<br style="clear: right" />
 	
-	</div><!-- #content -->
+	</div><!-- #footer -->
 
 </div><!-- #wrap -->
 
 </body>
-</html>
\ No newline at end of file
+</html>
